@@ -17,7 +17,7 @@
 #include <crypto/algapi.h>
 
 void wg_cookie_checker_init(struct cookie_checker *checker,
-			    struct wireguard_device *wg)
+			    struct wg_device *wg)
 {
 	init_rwsem(&checker->secret_lock);
 	checker->secret_birthdate = ktime_get_boot_fast_ns();
@@ -58,7 +58,7 @@ void wg_cookie_checker_precompute_device_keys(struct cookie_checker *checker)
 	}
 }
 
-void wg_cookie_checker_precompute_peer_keys(struct wireguard_peer *peer)
+void wg_cookie_checker_precompute_peer_keys(struct wg_peer *peer)
 {
 	precompute_key(peer->latest_cookie.cookie_decryption_key,
 		       peer->handshake.remote_static, cookie_key_label);
@@ -154,7 +154,7 @@ out:
 }
 
 void wg_cookie_add_mac_to_packet(void *message, size_t len,
-				 struct wireguard_peer *peer)
+				 struct wg_peer *peer)
 {
 	struct message_macs *macs = (struct message_macs *)
 		((u8 *)message + len - sizeof(*macs));
@@ -169,7 +169,7 @@ void wg_cookie_add_mac_to_packet(void *message, size_t len,
 	down_read(&peer->latest_cookie.lock);
 	if (peer->latest_cookie.is_valid &&
 	    !wg_birthdate_has_expired(peer->latest_cookie.birthdate,
-			 COOKIE_SECRET_MAX_AGE - COOKIE_SECRET_LATENCY))
+				COOKIE_SECRET_MAX_AGE - COOKIE_SECRET_LATENCY))
 		compute_mac2(macs->mac2, message, len,
 			     peer->latest_cookie.cookie);
 	else
@@ -196,9 +196,9 @@ void wg_cookie_message_create(struct message_handshake_cookie *dst,
 }
 
 void wg_cookie_message_consume(struct message_handshake_cookie *src,
-			       struct wireguard_device *wg)
+			       struct wg_device *wg)
 {
-	struct wireguard_peer *peer = NULL;
+	struct wg_peer *peer = NULL;
 	u8 cookie[COOKIE_LEN];
 	bool ret;
 
@@ -226,9 +226,10 @@ void wg_cookie_message_consume(struct message_handshake_cookie *src,
 		peer->latest_cookie.is_valid = true;
 		peer->latest_cookie.have_sent_mac1 = false;
 		up_write(&peer->latest_cookie.lock);
-	} else
+	} else {
 		net_dbg_ratelimited("%s: Could not decrypt invalid cookie response\n",
 				    wg->dev->name);
+	}
 
 out:
 	wg_peer_put(peer);
