@@ -6,7 +6,7 @@
 #ifndef _WG_NETLINK_H
 #define _WG_NETLINK_H
 
-int genetlink_init(void);
-void genetlink_uninit(void);
+int wg_genetlink_init(void);
+void wg_genetlink_uninit(void);
 
 #endif /* _WG_NETLINK_H */
